Module error

Module error 

Error types for the Dune API client

This module provides the error types for the Dune API client, built on top of the shared ApiError infrastructure.

Enums

ApiError
Generic API error type with support for domain-specific errors
DomainError
Domain-specific errors for Dune API

Functions

execution_failed
Create an execution failed error
execution_timeout
Create an execution timeout error
insufficient_credits
Create an insufficient credits error
invalid_api_key
Create an invalid API key error
not_found
Create a not found error

Type Aliases

Error
Error type for Dune API operations
Result
Result type for Dune API operations