ExecutionsApi

Struct ExecutionsApi 

pub struct ExecutionsApi<'a> { /* private fields */ }
Executions API

Implementations

Source

impl<'a> ExecutionsApi<'a>

pub async fn execute(&self, query_id: i64) -> Result<ExecuteQueryResponse>

Execute a saved query by ID

pub async fn execute_with_options( &self, query_id: i64, request: &ExecuteQueryRequest, ) -> Result<ExecuteQueryResponse>

Execute a saved query with options

pub async fn execute_sql( &self, request: &ExecuteSqlRequest, ) -> Result<ExecuteQueryResponse>

Execute raw SQL

pub async fn status(&self, execution_id: &str) -> Result<ExecutionStatus>

Get execution status

pub async fn results(&self, execution_id: &str) -> Result<ExecutionResult>

Get execution results

pub async fn results_with_options( &self, execution_id: &str, options: &GetResultsOptions, ) -> Result<ExecutionResult>

Get execution results with options

pub async fn results_csv(&self, execution_id: &str) -> Result<String>

Get execution results as CSV

pub async fn results_csv_with_options( &self, execution_id: &str, options: &GetResultsOptions, ) -> Result<String>

Get execution results as CSV with options

pub async fn cancel( &self, execution_id: &str, ) -> Result<CancelExecutionResponse>

Cancel an execution

pub async fn query_results(&self, query_id: i64) -> Result<ExecutionResult>

Get the latest results for a saved query (uses cached results if available)

pub async fn query_results_with_options( &self, query_id: i64, options: &GetResultsOptions, ) -> Result<ExecutionResult>

Get the latest results for a saved query with options

pub async fn query_results_csv(&self, query_id: i64) -> Result<String>

Get the latest results for a saved query as CSV

pub async fn query_results_csv_with_options( &self, query_id: i64, options: &GetResultsOptions, ) -> Result<String>

Get the latest results for a saved query as CSV with options

pub async fn run_query( &self, query_id: i64, timeout_secs: Option<u64>, ) -> Result<ExecutionResult>

Execute a query and wait for results (convenience method)

This method polls for completion with exponential backoff. Timeout is in seconds (default 300 = 5 minutes).

pub async fn run_query_with_options( &self, query_id: i64, request: &ExecuteQueryRequest, timeout_secs: Option<u64>, ) -> Result<ExecutionResult>

Execute a query with options and wait for results

pub async fn run_sql( &self, sql: &str, timeout_secs: Option<u64>, ) -> Result<ExecutionResult>

Execute SQL and wait for results (convenience method)

pub async fn run_sql_with_options( &self, request: &ExecuteSqlRequest, timeout_secs: Option<u64>, ) -> Result<ExecutionResult>

Execute SQL with options and wait for results